<?php
/*
Plugin Name: PrestaShop Integration
Description: Add integration using plugins and shortcodes from a PrestaShop e-commerce to your blog
Version: 0.2
Author: François Pons
Author URI: http://www.aytechnet.fr/
*/

/*  Copyright 2010  François Pons  (email : fpons@aytechnet.fr)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if ( !class_exists( 'PrestaShopIntegration' ) ) {
	class PrestaShopIntegration {
		var $pspath;
		var $psabspath;
		var $psdb;
		var $controller;

		function __construct() {
			load_plugin_textdomain( 'prestashop_integration', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

			if (function_exists('register_activation_hook'))
                                register_activation_hook(__FILE__, array(&$this, 'activate'));
                        if (function_exists('register_uninstall_hook'))
                                register_uninstall_hook(__FILE__, array('PrestaShopIntegration', 'uninstall'));

			$this->getOptions();

			if ( is_admin() ) {
				add_action( 'admin_init', array( &$this, 'registerOptions' ) );
				add_action( 'admin_menu', array( &$this, 'addAdminPages' ) );
			}
			add_action( 'widgets_init', array( &$this, 'registerWidgets' ) );
			add_action( 'wp_head', array( &$this, 'addPrestaShopHeaders' ) );

			add_shortcode('ps_product_list', array( &$this, 'shortcode_ps_product_list' ) );
		}

		function activate() {
			$options = get_option( 'prestashop_integration_options' );

			if ($options == false) {
				$options = array(
					'pspath' => '',
				);

				add_option( 'prestashop_integration_options', $options );
			} else {
				$options = $this->validateOptions( $options );

				update_option( 'prestashop_integration_options', $options );
			}
		}

		function uninstall() {
			delete_option( 'prestashop_integration_options' );
		}
			
		function getOptions() {
			$options = get_option( 'prestashop_integration_options' );

			$this->pspath = $options[ 'pspath' ];
			if ( preg_match( '#^/#', $this->pspath ) )
				$this->psabspath = $this->pspath;
			else
				$this->psabspath = ABSPATH . $this->pspath;
			if ( !preg_match( '#/$#', $this->psabspath ) )
				$this->psabspath .= '/';

			if ( file_exists( $this->psabspath . 'config/settings.inc.php' ) ) {
				require_once( $this->psabspath . 'config/settings.inc.php' );

				if ( DB_HOST == _DB_SERVER_ &&
				     DB_NAME == _DB_NAME_ &&
				     DB_USER == _DB_USER_ &&
				     DB_PASSWORD == _DB_PASSWD_ ) {
					global $wpdb;
					$this->psdb = $wpdb;
					error_log("PrestaShop Integration: using same database as WordPress one");
				} else {
					$this->psdb = new wpdb( _DB_USER_, _DB_PASSWD_, _DB_NAME_, _DB_SERVER_ );
					error_log("PrestaShop Integration: connecting to PrestaShop database");
				}
				$this->psprefix = _DB_PREFIX_;
			}
		}

		function registerOptions() {
			register_setting( 'prestashop_integration_group', 'prestashop_integration_options', array( &$this, 'validateOptions' ) );
		}

		function validateOptions( $input ) {
			$input[ 'pspath' ] = $input[ 'pspath' ]; #TODO check directory ?

			return $input;
		}

		function addAdminPages() {
			add_options_page( __( 'Configure PrestaShop Integration', 'prestashop_integration' ), __( 'PrestaShop Integration', 'prestashop_integration' ), 'manage_options', 'prestashop_integration_plugin', array( &$this, 'adminOptionPage' ) );
		}

		function adminOptionPage() {
			if ( ! current_user_can( 'manage_options' ) ) {
				wp_die( __( 'You do not have rights to access this page.', 'prestashop_integration' ));
			}
?>
<div class="wrap">
	<h2><?php _e( 'PrestaShop Integration' ); ?></h2>
	<form method="post" action="options.php">
		<?php settings_fields( 'prestashop_integration_group' ); ?>
		<?php _e( 'Define how to access the PrestaShop code and database: you need to give the absolute (or relative path from WordPress root installation) to PrestaShop root installation', 'prestashop_integration' ); ?>
		<table class="form-table">
			<tr align="top">
				<th scope="row"><?php _e( 'PrestaShop path:', 'prestashop_integration' ); ?></th>
				<td><input name="prestashop_integration_options[pspath]" value="<?php echo $this->pspath; ?>" /><?php echo $this->prestashopDescription(); ?></td>
			</tr>
		</table>
		<p class="submit">
			<input type="submit" class="button-primary" value="<?php _e( 'Save Changes' ); ?>" />
		</p>
	</form>
</div><?php
		}

		function registerWidgets() {
			require_once( dirname(__FILE__) . '/widgets/prestashop-integration-hook.php' );

			register_widget( 'PrestaShopIntegrationHook_Widget' );
		}

		function addPrestaShopHeaders() {
			if ( !$this->controller ) {
				require_once( dirname(__FILE__) . '/class/prestashop-integration-controller.php' );
				if ( class_exists( 'PrestaShopIntegration_FrontController' ) ) {
					$this->controller = new PrestaShopIntegration_FrontController;

					$this->controller->init();
					$this->controller->displayHeader();
				}
			}
                }

		function prestashopDescription() {
			if ($this->psdb) {
				echo '<br><span class="description">';
				printf( esc_attr__( 'The actual value "%s" refers to a PrestaShop installation version %s named "%s"', 'prestashop_integration' ), $this->pspath, $this->psConfiguration( 'PS_VERSION_DB' ), $this->psConfiguration( 'PS_SHOP_NAME' ) );
				echo '</span>';
			}
		}

		function psConfiguration( $name ) {
			if ($this->psdb)
				return $this->psdb->get_var( '
					SELECT `value`
					FROM `'.$this->psprefix.'configuration`
					WHERE `name` = "'.$name.'"' );
			else
				return false;
		}

		// [ps_product_list id_category=XX nb=N]
		function shortcode_ps_product_list($atts) {
			extract(shortcode_atts(array(
				'id_category' => '1',
				'nb' => '10',
			), $atts));

			if ( (int)$id_category > 0 ) {
				global $smarty;
				global $cookie;

				$category = new Category((int)$id_category, Configuration::get('PS_LANG_DEFAULT'));
				$products = $category->getProducts((int)($cookie->id_lang), 1, $nb);
				$smarty->assign(array(
					'products' => $products,
					'add_prod_display' => Configuration::get('PS_ATTRIBUTE_CATEGORY_DISPLAY'),
					'homeSize' => array( 'width' => 95, 'height' => 95 ))); /* FIXME: hack */
				return $smarty->display(_PS_THEME_DIR_.'product-list.tpl');
			}
		}
	}

	global $prestashop_integration;
	$prestashop_integration = new PrestaShopIntegration();
}
?>
